# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.insurance_pay_missing_primary_coverage_error_type import InsurancePayMissingPrimaryCoverageErrorType


class InsurancePayMissingPrimaryCoverageError(ApiError):
    def __init__(self, body: InsurancePayMissingPrimaryCoverageErrorType):
        super().__init__(status_code=422, body=body)
